@@ -29,7 +29,7 @@
 
 #include "config.h"
 
-#ifdef HAVE_JACK_SESSION_H
+#if HAVE_JACK_SESSION_H
 #include <jack/session.h>
 #endif
 
@@ -38,7 +38,7 @@ void audio_settings_init(GtkWidget* parent);
 void audio_settings_show(void);
 
 
-#ifdef HAVE_JACK_SESSION_H
+#if HAVE_JACK_SESSION_H
 void audio_settings_session_cb(jack_session_event_t *event, void *arg);
 #endif
 
