@@ -29,12 +29,14 @@
 #include <gtk/gtk.h>
 
 
-int         bank_ops_new     (void);
-int         bank_ops_open    (GtkWidget* parent_window);
-int         bank_ops_save_as (GtkWidget* parent_window);
-int         bank_ops_save    (GtkWidget* parent_window);
-const char* bank_ops_bank    (void);
-int         bank_ops_open_recent (GtkWidget* parent_window
-                , char* filename);
+int         bank_ops_new        (void);
+int         bank_ops_open       (GtkWidget* parent_window);
+int         bank_ops_open_recent(GtkWidget* parent_window, char* filename);
+int         bank_ops_import     (GtkWidget* parent_window);
+int         bank_ops_basic_save_as  (GtkWidget* parent_window);
+int         bank_ops_full_save_as   (GtkWidget* parent_window);
+int         bank_ops_save       (GtkWidget* parent_window);
+int         bank_ops_export     (GtkWidget* parent_window);
+
 
 #endif /* __BANK_OPS_H__ */
