@@ -24,9 +24,6 @@
 
 #include <stdbool.h>
 
-/*  global settings
-    
- */
 
 #define DEFAULT_LOG_LINES           100
 #define DEFAULT_ABS_MAX_SAMPLE      (1024 * 1024 * 1024)
@@ -39,14 +36,9 @@ typedef struct global_settings_def
     char*   last_sample_dir;
     char*   last_bank_dir;
     int     log_lines;
-/*
-    int     abs_max_sample_size;
-    int     max_sample_size;
- */
 
     char*   sample_file_filter;
     bool    sample_auto_preview;
-    float   sample_preview_length;
 
 } global_settings;
 
