@@ -37,9 +37,11 @@
 #include "bank-ops.h"
 #include "channelsection.h"
 #include "config.h"
+#include "dish_file.h"
 #include "driver.h"
 #include "global_settings.h"
 #include "gui.h"
+#include "log_display.h"
 #include "mastersection.h"
 #include "midisection.h"
 #include "mixer.h"
@@ -51,16 +53,17 @@
 #include "patch_util.h"
 #include "sample-editor.h"
 #include "sample-selector.h"
+#include "session.h"
 #include "waveform.h"
 
 
 /* windows */
-static GtkWidget* window;
-static GtkWidget* patch_section;
-static GtkWidget* master_section;
-static GtkWidget* midi_section;
-static GtkWidget* channel_section;
-static GtkWidget* patch_list;
+static GtkWidget* window = 0;
+static GtkWidget* patch_section = 0;
+static GtkWidget* master_section = 0;
+static GtkWidget* midi_section = 0;
+static GtkWidget* channel_section = 0;
+static GtkWidget* patch_list = 0;
 
 
 /* main menu */
@@ -68,14 +71,25 @@ static GtkWidget* menubar = 0;
 static GtkWidget* menu_file = 0;
 static GtkWidget* menu_settings = 0;
 static GtkWidget* menu_patch = 0;
+static GtkWidget* menu_view = 0;
 static GtkWidget* menu_help = 0;
-static GtkWidget* menuitem_file_recent = 0;
 
+/* file menu */
+static GtkWidget* menu_file_new = 0;
+static GtkWidget* menu_file_open = 0;
+static GtkWidget* menu_file_import = 0;
+static GtkWidget* menu_file_recent = 0;
+static GtkWidget* menu_file_save = 0;
+static GtkWidget* menu_file_basic_save_as = 0;
+static GtkWidget* menu_file_full_save_as = 0;
+static GtkWidget* menu_file_export = 0;
 
 /* settings */
-/*static GtkWidget* menu_settings_fans = 0;*/
 static GtkWidget* menu_settings_auto_preview = 0;
 
+/* view */
+static GtkWidget* menu_view_log_display = 0;
+
 /* current patch, makes passing patch id to sample editor easier */
 static int cur_patch = -1;
 
@@ -276,6 +290,7 @@ void cb_menu_patch_add(GtkWidget* menu_item, gpointer data)
     if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
     {
         int id = patch_create();
+        const char* name = gtk_entry_get_text(GTK_ENTRY(entry));
 
         if (id < 0)
         {
@@ -284,12 +299,10 @@ void cb_menu_patch_add(GtkWidget* menu_item, gpointer data)
             return;
         }
 
-        patch_set_name(id, (char *)gtk_entry_get_text(GTK_ENTRY(entry)));
-
-        patch_set_channel(id,
-                channel_section_get_channel(
-                        CHANNEL_SECTION(channel_section)));
-
+        patch_set_name(id, name);
+        patch_set_channel(id, channel_section_get_channel(
+                                    CHANNEL_SECTION(channel_section)));
+        msg_log(MSG_MESSAGE, "created new patch '%s'\n", name);
         patch_list_update(PATCH_LIST(patch_list), id, PATCH_LIST_PATCH);
     }
 
@@ -312,6 +325,7 @@ void cb_menu_patch_add_default(GtkWidget* menu_item, gpointer data)
     patch_set_channel(id,
             channel_section_get_channel(
                         CHANNEL_SECTION(channel_section)));
+    msg_log(MSG_MESSAGE, "added Default patch\n");
 
     patch_list_update(PATCH_LIST(patch_list), id, PATCH_LIST_PATCH);
 }
@@ -336,6 +350,9 @@ void cb_menu_patch_duplicate(GtkWidget* menu_item, gpointer data)
         return;
     }
 
+    msg_log(MSG_MESSAGE, "patch %d duplicated as %d '%s'\n", cp, id,
+                                                    patch_get_name(id));
+
     patch_list_update(PATCH_LIST(patch_list), id, PATCH_LIST_PATCH);
 }
 
@@ -392,8 +409,9 @@ void cb_menu_patch_rename(GtkWidget* menu_item, gpointer data)
      * due to sensitivity callback */
     if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
     {
-        val = patch_set_name (cp,
-                (char *)gtk_entry_get_text (GTK_ENTRY (entry)));
+        const char* oname = patch_get_name(cp);
+        const char* name = gtk_entry_get_text(GTK_ENTRY(entry));
+        val = patch_set_name(cp, name);
 
         if (val < 0)
         {
@@ -402,6 +420,7 @@ void cb_menu_patch_rename(GtkWidget* menu_item, gpointer data)
             return;
         }
 
+        msg_log(MSG_MESSAGE, "patch '%s' renamed as '%s'\n", oname, name);
         index = patch_list_get_current_index (PATCH_LIST(patch_list));
         patch_list_update (PATCH_LIST(patch_list), index, PATCH_LIST_INDEX);
     }
@@ -416,6 +435,7 @@ void cb_menu_patch_remove(GtkWidget* menu_item, gpointer data)
 
     int cp;
     int index;
+    const char* name;
 
     if ((cp = patch_list_get_current_patch(PATCH_LIST(patch_list))) < 0)
     {
@@ -423,9 +443,12 @@ void cb_menu_patch_remove(GtkWidget* menu_item, gpointer data)
         return;
     }
 
+    name = patch_get_name(cp);
     index = patch_list_get_current_index (PATCH_LIST(patch_list));
     patch_destroy(cp);
 
+    msg_log(MSG_MESSAGE, "destroyed patch '%s'\n", name);
+
     if (index == 0)
         patch_list_update(PATCH_LIST(patch_list), index,
                                                     PATCH_LIST_INDEX);
@@ -435,39 +458,49 @@ void cb_menu_patch_remove(GtkWidget* menu_item, gpointer data)
 }
 
 
-static void cb_menu_file_new_bank (GtkWidget * widget, gpointer data)
+static void cb_menu_file_new_bank(GtkWidget * widget, gpointer data)
 {
     (void)widget;(void)data;
-    if (bank_ops_new ( ) == 0)
-    {
-        patch_list_update (PATCH_LIST(patch_list), 0, PATCH_LIST_INDEX);
-        master_section_update(MASTER_SECTION(master_section));
-    }
+    if (bank_ops_new() == 0)
+        gui_refresh();
 }
 
-
-static void cb_menu_file_open_bank (GtkWidget * widget, gpointer data)
+static void cb_menu_file_open_bank(GtkWidget * widget, gpointer data)
 {
     (void)widget;(void)data;
     if (bank_ops_open(window) == 0)
-    {
-        patch_list_update (PATCH_LIST(patch_list), 0, PATCH_LIST_INDEX);
-        master_section_update(MASTER_SECTION(master_section));
-    }
+        gui_refresh();
 }
 
+static void cb_menu_file_import(GtkWidget * widget, gpointer data)
+{
+    (void)widget;(void)data;
+    if (bank_ops_import(window) == 0)
+        gui_refresh();
+}
 
-static void cb_menu_file_save_bank (GtkWidget * widget, gpointer data)
+static void cb_menu_file_save(GtkWidget * widget, gpointer data)
 {
     (void)widget;(void)data;
     bank_ops_save(window);
 }
 
-
-static void cb_menu_file_save_bank_as (GtkWidget * widget, gpointer data)
+static void cb_menu_file_basic_save_as(GtkWidget * widget, gpointer data)
 {
     (void)widget;(void)data;
-    bank_ops_save_as(window);
+    bank_ops_basic_save_as(window);
+}
+
+static void cb_menu_file_full_save_as(GtkWidget * widget, gpointer data)
+{
+    (void)widget;(void)data;
+    bank_ops_full_save_as(window);
+}
+
+static void cb_menu_file_export(GtkWidget * widget, gpointer data)
+{
+    (void)widget;(void)data;
+    bank_ops_export(window);
 }
 
 
@@ -478,16 +511,6 @@ static void cb_menu_settings_audio (GtkWidget * widget, gpointer data)
 }
 
 
-/*
-static void cb_menu_settings_fans(GtkWidget* widget, gpointer data)
-{
-    (void)widget;(void)data;
-    phin_fan_slider_set_fans_active(
-        gtk_check_menu_item_get_active(
-            GTK_CHECK_MENU_ITEM(menu_settings_fans)));
-}
-*/
-
 static void cb_menu_settings_auto_preview(GtkWidget* widget, gpointer data)
 {
     (void)widget;(void)data;
@@ -496,6 +519,31 @@ static void cb_menu_settings_auto_preview(GtkWidget* widget, gpointer data)
                         GTK_CHECK_MENU_ITEM(menu_settings_auto_preview));
 }
 
+
+void cb_menu_view_log_display_showing(gboolean active)
+{
+    gtk_check_menu_item_set_active(
+                    GTK_CHECK_MENU_ITEM(menu_view_log_display), active);
+}
+
+
+static void cb_menu_view_log_display(GtkWidget* widget, gpointer data)
+{
+    (void)widget; (void)data;
+    if (gtk_check_menu_item_get_active(
+                GTK_CHECK_MENU_ITEM(menu_view_log_display)))
+    {
+        log_display_show();
+    }
+    else
+        log_display_hide();
+}
+
+
+
+
+
+
 static void cb_menu_help_stfu (GtkWidget* widget, gpointer data)
 {
     (void)widget;(void)data;
@@ -519,9 +567,21 @@ static void cb_menu_help_about (GtkWidget* widget, gpointer data)
         "logo", logo,
         "authors", authors,
         "version", VERSION,
+        "website", "http://petri-foo.sourceforge.net/",
         "copyright",    "(C) 2004-2005 Pete Bessman\n"
                         "(C) 2006-2007 others\n"
                         "(C) 2011-2012 James Morris\n",
+        "comments",
+        #if HAVE_LIBLO
+        "Built with Non-Session-Manager support\n"
+        #else
+        "Built without Non-Session-Manager support\n"
+        #endif
+        #if HAVE_JACK_SESSION_H
+        "Built with JACK Session Support",
+        #else
+        "Built without JACK Session Support",
+        #endif
         NULL);
 }
 
@@ -531,8 +591,6 @@ static void cb_patch_list_changed(PatchList* list, gpointer data)
     (void)data;
     cur_patch = patch_list_get_current_patch(list);
 
-    debug("patch list changed patch:%d!\n",cur_patch);
-
     if (cur_patch < 0)
         sample_editor_hide();
     else if (sample_editor_get_visible())
@@ -557,16 +615,17 @@ static void cb_recent_chooser_item_activated (GtkRecentChooser *chooser
     recentInfo = gtk_recent_chooser_get_current_item(chooser);
     gtk_recent_manager_add_item(recent_manager, uri);
     gtk_recent_info_unref(recentInfo);
+
     if (bank_ops_open_recent(window, (char*) filename) == 0)
     {
-        patch_list_update (PATCH_LIST(patch_list), 0, PATCH_LIST_INDEX);
-        master_section_update(MASTER_SECTION(master_section));
+        gui_refresh();
     }
-     
+
     g_free(uri);
     g_free(filename);
 }
 
+
 int gui_init(void)
 {
     GtkWidget* window_vbox;
@@ -595,18 +654,48 @@ int gui_init(void)
 
     menu_file = gui_menu_add(menubar, "File", NULL, NULL);
 
-    gui_menu_add(menu_file, "New Bank",
+    menu_file_new = gui_menu_add(menu_file, "New",
             G_CALLBACK(cb_menu_file_new_bank),      window);
-    gui_menu_add(menu_file, "Open Bank...",
+    menu_file_open = gui_menu_add(menu_file, "Open...",
             G_CALLBACK(cb_menu_file_open_bank),     window);
+    menu_file_import = gui_menu_add(menu_file, "Import...",
+            G_CALLBACK(cb_menu_file_import),        window);
+
+    gtk_widget_set_tooltip_text(menu_file_new,
+                                "New bank");
+    gtk_widget_set_tooltip_text(menu_file_open,
+                                "Open a saved bank");
+    gtk_widget_set_tooltip_text(menu_file_import,
+                                "Import a saved bank into current bank");
+
+    menu_file_recent = gtk_menu_item_new_with_label("Open Recent");
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_file), menu_file_recent);
+
+    /* seperator */
+    gui_menu_add(menu_file, NULL, NULL, NULL);
+
+    menu_file_save = gui_menu_add(menu_file, "Save",
+            G_CALLBACK(cb_menu_file_save),          window);
+
+    menu_file_basic_save_as =
+        gui_menu_add(menu_file, "Save As...",
+            G_CALLBACK(cb_menu_file_basic_save_as),  window);
+
+    menu_file_full_save_as =
+        gui_menu_add(menu_file, "Full Save As...",
+            G_CALLBACK(cb_menu_file_full_save_as),  window);
+
+    menu_file_export = gui_menu_add(menu_file,"Export from session...",
+            G_CALLBACK(cb_menu_file_export),       window);
+    gtk_widget_set_sensitive(menu_file_export, FALSE);
+
+    gtk_widget_set_tooltip_text(menu_file_save,
+                                "Save bank");
+    gtk_widget_set_tooltip_text(menu_file_basic_save_as,
+                                "Basic Save bank as");
+    gtk_widget_set_tooltip_text(menu_file_full_save_as,
+                    "Full bank save, link samples, ready for archiving");
 
-    menuitem_file_recent = gtk_menu_item_new_with_label("Open Recent");
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_file), menuitem_file_recent);   
-    gui_menu_add(menu_file, "Save Bank",
-            G_CALLBACK(cb_menu_file_save_bank),     window);
-    gui_menu_add(menu_file, "Save Bank As...",
-            G_CALLBACK(cb_menu_file_save_bank_as),  window);
- 
     /* seperator */
     gui_menu_add(menu_file, NULL, NULL, NULL);
     gui_menu_add(menu_file, "Quit", G_CALLBACK(cb_quit), NULL);
@@ -629,19 +718,6 @@ int gui_init(void)
     gui_menu_add(menu_settings, "Audio...",
             G_CALLBACK(cb_menu_settings_audio),     NULL);
 
-    /* use slider fans
-    menu_settings_fans =
-        gtk_check_menu_item_new_with_label("Use slider fans");
-    gtk_check_menu_item_set_active(
-        GTK_CHECK_MENU_ITEM(menu_settings_fans),
-            phin_fan_slider_get_fans_active());
-    g_signal_connect(GTK_OBJECT(menu_settings_fans), "toggled",
-        G_CALLBACK(cb_menu_settings_fans), NULL);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu_settings),
-                                        menu_settings_fans);
-    gtk_widget_show(menu_settings_fans);
-*/
-
     /* auto-preview */
     menu_settings_auto_preview =
         gtk_check_menu_item_new_with_label("Sample auto-preview");
@@ -656,14 +732,21 @@ int gui_init(void)
                                         menu_settings_auto_preview);
     gtk_widget_show(menu_settings_auto_preview);
 
+    /* view menu */
+    menu_view = gui_menu_add(menubar, "View", NULL, NULL);
+    menu_view_log_display =
+        gui_menu_check_add(menu_view, "Message Log", FALSE,
+                G_CALLBACK(cb_menu_view_log_display), window);
+
     /* help menu */
-    menu_help = gui_menu_add(menubar, "Help", NULL, NULL);
+    menu_help = gui_menu_add(menubar, ">Help", NULL, NULL);
     gui_menu_add(menu_help, "All Sound Off!",
             G_CALLBACK(cb_menu_help_stfu),          NULL);
     gui_menu_add(menu_help, "About...",
             G_CALLBACK(cb_menu_help_about),         window);
 
-    gui_recent_files_load();
+    if (!session_is_nsm())
+        gui_recent_files_load();
 
     gtk_widget_show_all(menubar);
 
@@ -719,10 +802,14 @@ int gui_init(void)
     /* intialize children */
     sample_editor_init(window);
     audio_settings_init(window);
+    log_display_init(window);
 
     /* priming updates */
-    master_section_update(MASTER_SECTION(master_section));
-    patch_list_update(PATCH_LIST(patch_list), 0, PATCH_LIST_INDEX);
+
+    if (session_is_active())
+        gui_set_session_mode();
+
+    gui_refresh();
 
     return 0;
 }
@@ -730,11 +817,14 @@ int gui_init(void)
 
 void gui_refresh(void)
 {
-    gui_set_window_title(bank_ops_bank());
+    const char* title = dish_file_state_path();
+    gui_set_window_title_bank(title ? title : "Untitled");
     master_section_update(MASTER_SECTION(master_section));
     patch_list_update(PATCH_LIST(patch_list), 0, PATCH_LIST_INDEX);
     cb_patch_list_changed(PATCH_LIST(patch_list), NULL);
-    gui_recent_files_load();
+
+    if (!session_is_nsm())
+        gui_recent_files_load();
 }
 
 
@@ -744,20 +834,33 @@ PatchList* gui_get_patch_list(void)
 }
 
 
-void gui_set_window_title(const char* title)
+void gui_set_window_title_bank(const char* title)
 {
-    const char* name = driver_get_client_name();
+    static char* banktitle = 0;
+    const char* instancename = get_instance_name();
+    char buf[8000];
 
-    if (name)
+    if (!instancename)
+        instancename = PACKAGE;
+
+    if (session_is_nsm())
     {
-        char buf[80];
-        sprintf(buf, "%s - %s", name, (title) ? title : "Untitled");
-
-        gtk_window_set_title (GTK_WINDOW (window), buf);
+        gtk_window_set_title(GTK_WINDOW(window), instancename);
+        return;
     }
-    else
-        gtk_window_set_title (GTK_WINDOW (window), PACKAGE);
 
+    if (title)
+    {
+        free(banktitle);
+        banktitle = strdup(title);
+    }
+
+    snprintf(buf, 7999, "%s - %s", instancename, (banktitle) ? banktitle
+                                                           : "Untitled");
+    buf[7999] = '\0';
+
+    if (window)
+        gtk_window_set_title(GTK_WINDOW(window), buf);
 }
 
 
@@ -769,6 +872,14 @@ GtkWidget* gui_menu_add(GtkWidget* menu, const char* label, GCallback cb,
 
     if (label)
     {
+        gboolean rightjustify = FALSE;
+
+        if (*label == '>')
+        {
+            ++label;
+            rightjustify = TRUE;
+        }
+
         item = gtk_menu_item_new_with_label(label);
 
         if (cb)
@@ -778,6 +889,9 @@ GtkWidget* gui_menu_add(GtkWidget* menu, const char* label, GCallback cb,
             submenu = gtk_menu_new();
             gtk_menu_item_set_submenu(GTK_MENU_ITEM(item), submenu);
         }
+
+        if (rightjustify)
+            gtk_menu_item_set_right_justified (GTK_MENU_ITEM(item), TRUE);
     }
     else
         item = gtk_menu_item_new();
@@ -803,34 +917,48 @@ gui_menu_check_add(GtkWidget* menu, const char* label,  gboolean active,
     return item;
 }
 
+
+void gui_set_session_mode(void)
+{
+    debug("GUI entering session mode\n");
+    gtk_widget_set_sensitive(menu_file_open, FALSE);
+    gtk_widget_set_sensitive(menu_file_recent, FALSE);
+    gtk_widget_set_sensitive(menu_file_basic_save_as, FALSE);
+    gtk_widget_set_sensitive(menu_file_full_save_as, FALSE);
+    gtk_menu_item_set_label(GTK_MENU_ITEM(menu_file_save),
+                            "Save session bank");
+    gtk_widget_set_sensitive(menu_file_export, TRUE);
+}
+
+
 /* recent items menu */
 void gui_recent_files_load(void) 
 {
     GtkRecentFilter *recent_filter;
-    GtkWidget *menuitem_file_recent_items;
+    GtkWidget *menu_file_recent_items;
     recent_manager = gtk_recent_manager_get_default();
     recent_filter = gtk_recent_filter_new();
     gtk_recent_filter_add_mime_type(recent_filter,
                                     "application/x-petri-foo");
-    menuitem_file_recent_items = 
+    menu_file_recent_items = 
             gtk_recent_chooser_menu_new_for_manager(recent_manager);
     gtk_recent_chooser_add_filter(
-            GTK_RECENT_CHOOSER(menuitem_file_recent_items), recent_filter);
+            GTK_RECENT_CHOOSER(menu_file_recent_items), recent_filter);
     gtk_recent_chooser_set_show_tips(
-            GTK_RECENT_CHOOSER(menuitem_file_recent_items), TRUE);
+            GTK_RECENT_CHOOSER(menu_file_recent_items), TRUE);
     gtk_recent_chooser_set_sort_type(
-            GTK_RECENT_CHOOSER(menuitem_file_recent_items),
+            GTK_RECENT_CHOOSER(menu_file_recent_items),
             GTK_RECENT_SORT_MRU);
     gtk_recent_chooser_set_limit(
-            GTK_RECENT_CHOOSER(menuitem_file_recent_items), 10);
+            GTK_RECENT_CHOOSER(menu_file_recent_items), 10);
     gtk_recent_chooser_set_local_only(
-            GTK_RECENT_CHOOSER(menuitem_file_recent_items), FALSE);
+            GTK_RECENT_CHOOSER(menu_file_recent_items), FALSE);
     gtk_recent_chooser_menu_set_show_numbers(
-            GTK_RECENT_CHOOSER_MENU(menuitem_file_recent_items), TRUE);
-    g_signal_connect(GTK_OBJECT(menuitem_file_recent_items),
+            GTK_RECENT_CHOOSER_MENU(menu_file_recent_items), TRUE);
+    g_signal_connect(GTK_OBJECT(menu_file_recent_items),
                     "item-activated",
                      G_CALLBACK(cb_recent_chooser_item_activated), window);
-    gtk_menu_item_set_submenu(GTK_MENU_ITEM(menuitem_file_recent), 
-            menuitem_file_recent_items);
+    gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_file_recent), 
+            menu_file_recent_items);
 
 }
