@@ -410,6 +410,7 @@ static void lfo_tab_init(LfoTab* self)
                     ID_SELECTOR_V);
 
     mod_src_free(lfo_ids);
+    lfo_ids = 0;
 
     gui_pack(selfbox, p->idsel);
     gui_pack(selfbox, gui_hpad_new(GUI_SECSPACE));
@@ -553,18 +554,16 @@ static void update_lfo(LfoTabPrivate* p)
     float fm1amt, fm2amt;
     int   am1src, am2src;
     float am1amt, am2amt;
+    int mod_srcs;
 
     GtkTreeIter fm1iter, fm2iter;
     GtkTreeIter am1iter, am2iter;
 
     p->lfo_id = id_selector_get_id(ID_SELECTOR(p->idsel));
 
-    debug("UPDATE LFO\t\tgot lfo id:%d\n", p->lfo_id);
-
-    int mod_srcs = (mod_src_is_global(p->lfo_id)
+    mod_srcs = (mod_src_is_global(p->lfo_id)
                         ? MOD_SRC_GLOBALS
                         : MOD_SRC_ALL);
-
     block(p);
     mod_src_combo_set_model(GTK_COMBO_BOX(p->fm1_combo), mod_srcs);
     mod_src_combo_set_model(GTK_COMBO_BOX(p->fm2_combo), mod_srcs);
@@ -572,9 +571,6 @@ static void update_lfo(LfoTabPrivate* p)
     mod_src_combo_set_model(GTK_COMBO_BOX(p->am2_combo), mod_srcs);
     unblock(p);
 
-    debug("getting lfo (id:%d) data from patch:%d\n",
-                                p->lfo_id,p->patch_id);
-
     lfoshape = patch_get_lfo_shape(     p->patch_id, p->lfo_id);
     freq = patch_get_lfo_freq(          p->patch_id, p->lfo_id);
     beats = patch_get_lfo_sync_beats(   p->patch_id, p->lfo_id);
@@ -599,8 +595,6 @@ static void update_lfo(LfoTabPrivate* p)
     am2src = patch_get_lfo_am2_src(  p->patch_id, p->lfo_id);
     am2amt = patch_get_lfo_am2_amt(  p->patch_id, p->lfo_id);
 
-    debug("getting mod src combo iter with id\n");
-
     if (!mod_src_combo_get_iter_with_id(GTK_COMBO_BOX(p->fm1_combo),
                                                         fm1src, &fm1iter))
     {
@@ -625,14 +619,9 @@ static void update_lfo(LfoTabPrivate* p)
         debug("failed to get lfo fm2 source id from combo box\n");
     }
 
-
-    debug("...\n");
-
     block(p);
-
     phin_slider_set_value(PHIN_SLIDER(p->freq), freq);
 
-
     if (mod_src_is_global(p->lfo_id))
     {
         gtk_widget_hide(p->delay);
@@ -691,7 +680,6 @@ static void update_lfo(LfoTabPrivate* p)
     gtk_widget_set_sensitive(p->am2_amount, am2src != MOD_SRC_NONE);
 
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(p->lfo_check), active);
-
     unblock(p);
 }
 
