@@ -139,6 +139,9 @@ static void cb_load(raw_box* rb)
         }
     }
 
+    msg_log(MSG_MESSAGE, "loaded sample '%s' for patch %d '%s'\n",
+                                name, patch, patch_get_name(patch));
+
     if (name)
     {
         char* dirname = g_path_get_dirname(name);
@@ -177,7 +180,7 @@ static void cb_load(raw_box* rb)
 fail:
     if (!name)
     {   /* I don't really think this is possible, but hey. */
-        errmsg("no file selected\n");
+        msg_log(MSG_ERROR, "no file selected\n");
         msg = gtk_message_dialog_new(GTK_WINDOW(rb->dialog),
                                      GTK_DIALOG_DESTROY_WITH_PARENT,
                                      GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
@@ -185,8 +188,7 @@ fail:
     }
     else
     {
-        msg_log(MSG_TYPE_ERROR, /*  Unlike MSG_ERROR, MSG_TYPE_ERROR does
-                                    not set the log notification flag */
+        msg_log(MSG_ERROR,
                 "Failed to load sample %s for patch %d (%s)\n",
                 name, patch, pf_error_str(err));
 
