@@ -28,17 +28,19 @@
 #include "config.h"
 
 #include <jack/jack.h>
+#include <stdbool.h>
 
-#ifdef HAVE_JACK_SESSION_H
+#if HAVE_JACK_SESSION_H
 #include <jack/session.h>
-void            jackdriver_set_session_cb(JackSessionCallback jacksession_cb);
+void jackdriver_set_session_cb(JackSessionCallback jacksession_cb);
 #endif
 
-
-void            jackdriver_set_unconnected(void);
+void            jackdriver_set_autoconnect(bool);
 void            jackdriver_set_uuid(char *uuid);
 jack_client_t*  jackdriver_get_client(void);
 
+/*  if this needs to be called do so before starting jack */
+void            jackdriver_disable_jacksession(void);
 
 
 #endif /* __JACKDRIVER_H__ */
