@@ -25,8 +25,9 @@
 #include "patch_set_and_get.h"
 
 #include <assert.h>
-#include <string.h>
 #include <math.h>
+#include <string.h>
+#include <unistd.h>
 
 
 #include "sample.h"
@@ -35,6 +36,7 @@
 #include "pf_error.h"
 
 
+#include "patch_private/err_msg.h"
 #include "patch_private/patch_data.h"
 #include "patch_private/patch_defs.h"
 #include "patch_private/patch_macros.h"
@@ -297,11 +299,13 @@ static LFOParams* lfopar_from_id(int patch_id, int id, LFO** lfo)
 
     if (id & MOD_SRC_VLFO)
     {
-        assert ((id -= MOD_SRC_VLFO) < VOICE_MAX_LFOS);
+        id -= MOD_SRC_VLFO;
+        assert (id < VOICE_MAX_LFOS);
         return &patches[patch_id]->vlfo_params[id];
     }
 
-    assert((id -= MOD_SRC_GLFO) < PATCH_MAX_LFOS);
+    id -= MOD_SRC_GLFO;
+    assert(id < PATCH_MAX_LFOS);
 
     if (lfo)
         *lfo = patches[patch_id]->glfo[id];
@@ -374,6 +378,7 @@ PATCH_GET_LFO_VAR( sync,       bool )
 /************************ PARAMETER SETTERS *******************************/
 /**************************************************************************/
 
+
 /* sets the cut signal this patch emits when activated */
 int patch_set_cut (int patch_id, int cut)
 {
@@ -792,12 +797,10 @@ bool patch_get_monophonic(int patch_id)
 }
 
 /* get the name */
-char *patch_get_name(int patch_id)
+const char *patch_get_name(int patch_id)
 {
-    char *name;
     assert(patchok(patch_id));
-    name = strdup (patches[patch_id]->name);
-    return name;
+    return patches[patch_id]->name;
 }
 
 
